/*
 * Copyright (c) 2009, Manuel Mausz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY <copyright holder> ''AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL <copyright holder> BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#define VERSION "0.1"

#define _GNU_SOURCE
#define CORE_PRIVATE
#include "httpd.h"
#include "http_config.h"
#include "http_core.h"
#include "http_log.h"
#include "http_main.h"
#include "http_request.h"
#include "http_conf_globals.h"
#include <linux/oom.h>

#define OOM_ADJUST_VALUE OOM_ADJUST_MAX

module MODULE_VAR_EXPORT oomadj_module;

static void
oomadj_init(server_rec *s, pool *p)
{
  FILE *fp;

  fp = fopen("/proc/self/oom_adj", "w");
  if (fp != NULL)
  {
    fprintf(fp, "%d", OOM_ADJUST_VALUE);
    fclose(fp);
    ap_log_error(APLOG_MARK, APLOG_NOERRNO|APLOG_NOTICE, s, "oom_adj adjusted");
    return;
  }

  ap_log_error(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, s, "Error: Unable to adjust oom_adj.");
  return;
}

module MODULE_VAR_EXPORT oomadj_module =
{
    STANDARD_MODULE_STUFF,
    oomadj_init,                        /* initializer */
    NULL,                               /* dir config creater */
    NULL,                               /* dir merger: default is to override */
    NULL,                               /* server config */
    NULL,                               /* merge server config */
    NULL,                               /* command table */
    NULL,                               /* handlers */
    NULL,                               /* filename translation */
    NULL,                               /* check_user_id */
    NULL,                               /* check auth */
    NULL,                               /* check access */
    NULL,                               /* type_checker */
    NULL,                               /* fixups */
    NULL,                               /* logger */
    NULL,                               /* header parser */
    NULL,                               /* child_init */
    NULL,                               /* child_exit */
    NULL,                               /* post read-request */
};
